@@ -15,7 +15,7 @@ from selenium.common.exceptions import NoSuchElementException
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.remote.remote_connection import LOGGER
-from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
+import undetected_chromedriver.v2 as uc
 
 import logging
 import platform
@@ -24,7 +24,19 @@ import base64
 class Selenium(Scraper):
 
     def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None):
-        options = webdriver.ChromeOptions()
+
+        if user_dir is None:
+            options = webdriver.ChromeOptions()
+        else:
+            options = uc.ChromeOptions()
+
+            # another way to set profile is the below (which takes precedence if both variants are used
+            options.add_argument(f'--user-data-dir={user_dir}')
+            # just some options passing in to skip annoying popups
+            options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
+
+        #Remove navigator.webdriver Flag using JavaScript
+        options.add_argument('--disable-blink-features=AutomationControlled')
 
         #region options
         options.add_argument('--no-sandbox')
@@ -48,11 +60,14 @@ class Selenium(Scraper):
 
         options.add_argument('--disable-blink-features=AutomationControlled')
         options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36")
+
         #endregion options
 
         url = config.get(section='SELENIUM', key='url')
 
-        if url is not None:
+        if user_dir is not None:
+            self.driver = uc.Chrome(options=options)            
+        elif url is not None:
             self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
         elif platform.system() == 'Windows':
             self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
